@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package WWW::Spotify;
-$WWW::Spotify::VERSION = '0.007';
+$WWW::Spotify::VERSION = '0.008';
 use Moo 2.002004;
 
 use Data::Dumper;
@@ -9,7 +9,8 @@ use File::Basename;
 use HTTP::Headers;
 use IO::CaptureOutput qw( capture qxx qxy );
 use JSON::Path;
-use JSON::XS;
+use JSON::MaybeXS qw( decode_json );
+use LWP::Protocol::https ();
 use MIME::Base64;
 use Scalar::Util;
 use Try::Tiny qw( catch try );
@@ -969,7 +970,7 @@ WWW::Spotify - Spotify Web API Wrapper
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
